# Crabatar
![Codecov](https://img.shields.io/codecov/c/github/jakeledoux/crabatar)
![Python package](https://github.com/jakeledoux/crabatar/workflows/Python%20package/badge.svg)
![PyPI](https://img.shields.io/pypi/v/crabatar)

Generate crab-themed avatars procedurally from usernames.

*Developed for [Crabber](https://github.com/jakeledoux/crabber/)*

## Installation

``` bash
pip install crabatar
```

![Sample Avatars](sample.png)
